MockProvider

Struct MockProvider 

pub struct MockProvider { /* private fields */ }
A mock Provider for testing.

Responses are consumed from an internal queue in FIFO order. If the queue is empty a default stub response/chunk is returned.

Implementations

Source

impl MockProvider

pub fn new() -> Self

Create a new, empty mock provider.

pub fn push_response(&self, response: Response)

Enqueue a response to be returned by the next call to complete.

pub fn push_stream(&self, stream_chunks: Vec<Chunk>)

Enqueue a sequence of chunks to be emitted by the next call to stream.