pub struct MockProvider { /* private fields */ }Expand description
A mock Provider for testing.
Responses are consumed from an internal queue in FIFO order. If the queue is empty a default stub response/chunk is returned.
Implementations
Sourceimpl MockProvider
impl MockProvider
Sourcepub fn push_response(&self, response: Response)
pub fn push_response(&self, response: Response)
Enqueue a response to be returned by the next call to complete.
Sourcepub fn push_stream(&self, stream_chunks: Vec<Chunk>)
pub fn push_stream(&self, stream_chunks: Vec<Chunk>)
Enqueue a sequence of chunks to be emitted by the next call to stream.